@@ -23,7 +23,8 @@ int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
 
-    KLocalizedString::setApplicationDomain("ksquares");
+    KLocalizedString::setApplicationDomain(QByteArrayLiteral("ksquares"));
+
     KAboutData about(QStringLiteral("ksquares"), i18n("KSquares"),
                      QStringLiteral(KSQUARES_VERSION_STRING),
                      i18n("Take it in turns to draw lines.\nIf you complete a squares, you get another go."),
